# k3mime

[![Action-CI](https://github.com/pykit3/k3mime/actions/workflows/python-package.yml/badge.svg)](https://github.com/pykit3/k3mime/actions/workflows/python-package.yml)
[![Documentation Status](https://readthedocs.org/projects/k3mime/badge/?version=stable)](https://k3mime.readthedocs.io/en/stable/?badge=stable)
[![Package](https://img.shields.io/pypi/pyversions/k3mime)](https://pypi.org/project/k3mime)

This module provide some util methods to handle mime type.

k3mime is a component of [pykit3] project: a python3 toolkit set.


#   Table of Content

- [Name](#name)
- [Status](#status)
- [Synopsis](#synopsis)
- [Author](#author)
- [Copyright and License](#copyright-and-license)


#   Name

k3mime

#   Status

The library is considered production ready.




# Install

```
pip install k3mime
```

# Synopsis

```python

import k3mime

print(k3mime.get_by_filename('file.json'))
#  application/json


```

#   Author

Zhang Yanpo (张炎泼) <drdr.xp@gmail.com>

#   Copyright and License

The MIT License (MIT)

Copyright (c) 2015 Zhang Yanpo (张炎泼) <drdr.xp@gmail.com>


[pykit3]: https://github.com/pykit3